==> phpMyGPX-0.3.tar.bz2: phpmygpx/map.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

session_start();

include("./config.inc.php");
include("./libraries/functions.inc.php");
include("./libraries/classes.php");
include("./libraries/html.classes.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("./languages/".get_lang($cfg['config_language']).".php");
include("./head.html.php");

if($cfg['show_exec_time'])
    $startTime = microtime_float();

if($DEBUG) {
    foreach($_POST as $akey => $val)
        out("<b>$akey</b> = $val", "OUT_DEBUG");
}

$id = intval($_GET['id']);
$gpx = strip_tags($_GET['gpx']);
$f_lat = floatval($_GET['lat']);
$f_lon = floatval($_GET['lon']);
$zoom = intval($_GET['zoom']);
$marker = intval($_GET['marker']);

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

HTML::heading(_APP_NAME, 2);
HTML::main_menu();

if(!$zoom)	$zoom = 15;
if(!$f_lat || !$f_lon) {
	if($id) {
		if(!$gpx) {
			$query = "SELECT * FROM `${cfg['db_table_prefix']}gpx_files` 
						WHERE `id` = '$id' ;";
			$result = db_query($query);
			if($DEBUG)	out($query, 'OUT_DEBUG');
			if(mysql_num_rows($result)) {
				while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
					$gpx = $row['name'];
				}
			}
		}
		
	    $query = "SELECT `gpx_id`, 
			MIN(`latitude`) AS 'minlat', MAX(`latitude`) AS 'maxlat', AVG(`latitude`) AS 'avglat', 
			MIN(`longitude`) AS 'minlon', MAX(`longitude`) AS 'maxlon', AVG(`longitude`) AS 'avglon'
			FROM `${cfg['db_table_prefix']}gpx_import` WHERE `gpx_id` = '$id' GROUP BY `gpx_id` ;";
	    $result = db_query($query);
		if($DEBUG)	out($query, 'OUT_DEBUG');
	    if(mysql_num_rows($result)) {
	    	while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
				#$f_lat = $row['avglat'] /1000000;
				#$f_lon = $row['avglon'] /1000000;
				$f_minlat = $row['minlat'] /1000000;
				$f_maxlat = $row['maxlat'] /1000000;
				$f_minlon = $row['minlon'] /1000000;
				$f_maxlon = $row['maxlon'] /1000000;
	    	}
		}
	}else {
		$f_lat = $cfg['home_latitude'];
		$f_lon = $cfg['home_longitude'];
	}
}
?>

<!-- bring in the OpenLayers javascript library
	 (here we bring it from the remote site, but you could
	 easily serve up this javascript yourself)
	 URL: http://www.openlayers.org/api/OpenLayers.js -->
<script src="openlayers/OpenLayers.js"></script>
<!-- bring in the OpenStreetMap OpenLayers layers.
	 Using this hosted file will make sure we are kept up
	 to date with any necessary changes -->
<script src="http://www.openstreetmap.org/openlayers/OpenStreetMap.js"></script>
<script src="openlayers/GPX.js"></script>

<script type="text/javascript">
	// Start position for the map (hardcoded here for simplicity,
	// but maybe you want to get from URL params)
<?php
if($f_lat && $f_lon) {
?>	
	var lat=<?= $f_lat ?>;
	var lon=<?= $f_lon ?>;
	var zoom=<?= $zoom ?>;
<?php
}
?>	

	var map; //complex object of type OpenLayers.Map
 
	//Initialise the 'map' object
	function initMap() {
		map = new OpenLayers.Map ("map", {
			controls:[
				new OpenLayers.Control.Navigation(),
				new OpenLayers.Control.PanZoomBar(),
				new OpenLayers.Control.LayerSwitcher(),
				new OpenLayers.Control.Attribution()],
			maxExtent: new OpenLayers.Bounds(-20037508.34,-20037508.34,20037508.34,20037508.34),
			maxResolution: 156543.0399,
			numZoomLevels: 19,
			units: 'm',
			projection: new OpenLayers.Projection("EPSG:900913"),
			displayProjection: new OpenLayers.Projection("EPSG:4326")
		} );
 
 
		// Define the map layer
		// Note that we use a predefined layer that will be
		// kept up to date with URL changes
		// Here we define just one layer, but providing a choice
		// of several layers is also quite simple
		// Other defined layers are OpenLayers.Layer.OSM.Mapnik, OpenLayers.Layer.OSM.Maplint and OpenLayers.Layer.OSM.CycleMap
		
		layerMapnik = new OpenLayers.Layer.OSM.Mapnik("Mapnik");
		map.addLayer(layerMapnik);
		
		layerTilesAtHome = new OpenLayers.Layer.OSM.Osmarender("Osmarender");
		map.addLayer(layerTilesAtHome);
		
		layerCycleMap = new OpenLayers.Layer.OSM.CycleMap("CycleMap");
		map.addLayer(layerCycleMap);
		
<?php
if($marker && $f_lat && $f_lon) {
?>	
		layerMarkers = new OpenLayers.Layer.Markers("Markers");
		map.addLayer(layerMarkers);
		
<?php
}
if($gpx) {
?>
		// Add the Layer with GPX Track
		var lgpx = new OpenLayers.Layer.GPX("GPX-Track", "./files/<?= $gpx ?>", "#9900ff");
		map.addLayer(lgpx);
		
<?php
}
if($f_lat && $f_lon) {
?>	
		var lonLat = new OpenLayers.LonLat(lon, lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject());
		map.setCenter (lonLat, zoom);
		
<?php
}else {
		echo "var minlon=$f_minlon;";
		echo "var maxlon=$f_maxlon;";
		echo "var minlat=$f_minlat;";
		echo "var maxlat=$f_maxlat;";
?>
		bounds = new OpenLayers.Bounds();
		bounds.extend(new OpenLayers.LonLat(minlon, minlat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()));
		bounds.extend(new OpenLayers.LonLat(maxlon, maxlat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()));
		map.zoomToExtent(bounds);
		
<?php
}
if($marker && $f_lat && $f_lon) {
?>	
		var size = new OpenLayers.Size(21,25);
		var offset = new OpenLayers.Pixel(-(size.w/2), -size.h);
		var icon = new OpenLayers.Icon('http://www.openstreetmap.org/openlayers/img/marker.png',size,offset);
		layerMarkers.addMarker(new OpenLayers.Marker(lonLat,icon));
		
<?php
}
?>		
		// register event that records new lon/lat coordinates in form fields after panning
		map.events.register("moveend", map, function() {
			var pos = this.getCenter().clone();
			var lonlat = pos.transform(this.getProjectionObject(), new OpenLayers.Projection("EPSG:4326"));			
			var edit_bounds = map.getExtent();
			edit_bounds.transform(this.getProjectionObject(), new OpenLayers.Projection("EPSG:4326"));
			
			var bookmarklink = document.getElementById('bookmarklink');
			var searchlink = document.getElementById('searchlink');
			var josmlink = document.getElementById('josmlink');
			var osblink = document.getElementById('osblink');
			var keeprightlink = document.getElementById('keeprightlink');
			
			bookmarklink.value = "map.php?lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&zoom=" + this.getZoom();
			searchlink.href = "traces.php?task=view&option=search&lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&lat_range=" + edit_bounds.getHeight() + "&lon_range=" + edit_bounds.getWidth();
			josmlink.href = "http://localhost:8111/load_and_zoom?left=" + edit_bounds.left + "&right=" + edit_bounds.right + "&bottom=" + edit_bounds.bottom + "&top=" + edit_bounds.top;
			osblink.href = "http://openstreetbugs.org/?lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&z=" + this.getZoom();
			keeprightlink.href = "http://keepright.ipax.at/report_map.php?lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&zoom=" + this.getZoom();
		});
	
	// call event handler as if one had moved the map
	map.events.triggerEvent("moveend");

	}
</script>

<script type="text/javascript">
	function addBookmark() {
		bookmarkName = prompt("<?= _MAP_JS_BOOKM_NAME ?>", "");
		if(bookmarkName) {
			var bookmarkScript = "bookmark.php?task=add&name=" + encodeURI(bookmarkName) + "&url=";
			var bookmarkLink = String(document.getElementById('bookmarklink').value);
			document.location.href = bookmarkScript + encodeURIComponent(bookmarkLink);
		}
	}
</script>

<!-- define a DIV into which the map will appear. Make it take up the whole window -->
<div style="width:99%; height:66%;" id="map"></div>

<img src="images/b_bookmark.png" />
<input type="hidden" name="url" id="bookmarklink" />
<a href="JavaScript:addBookmark();"><?= _MAP_ADD_BOOKM ?></a><br />
<img src="images/b_select.png" />
<a href="" id="searchlink"><?= _MAP_AREA_TRKPT ?></a><br />
<img src="images/icon_josm.png" />
<a target="josm" href="" id="josmlink"><?= _MAP_JOSM_EDIT ?></a><br />
<img src="images/icon_osb.png" />
<a target="osb" href="" id="osblink">OpenStreetBugs</a><br />
<img src="images/icon_keepright.png" />
<a target="keepright" href="" id="keeprightlink">keep right!</a><br />

<?php
if($cfg['show_exec_time']) {
    $endTime = microtime_float();
    $exectime = round($endTime - $startTime, 4);
}
include("./foot.html.php");
?>

==> phpMyGPX-0.3.1.tar.bz2: phpmygpx/map.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

session_start();

include("./config.inc.php");
include("./libraries/functions.inc.php");
include("./libraries/classes.php");
include("./libraries/html.classes.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("./languages/".get_lang($cfg['config_language']).".php");
include("./head.html.php");

if($cfg['show_exec_time'])
    $startTime = microtime_float();

if($DEBUG) {
    foreach($_POST as $akey => $val)
        out("<b>$akey</b> = $val", "OUT_DEBUG");
}

$id = intval($_GET['id']);
$gpx = strip_tags($_GET['gpx']);
$f_lat = floatval($_GET['lat']);
$f_lon = floatval($_GET['lon']);
$zoom = intval($_GET['zoom']);
$marker = intval($_GET['marker']);

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

HTML::heading(_APP_NAME, 2);
HTML::main_menu();

if(!$zoom)	$zoom = 15;
if(!$f_lat || !$f_lon) {
	if($id) {
		if(!$gpx) {
			$query = "SELECT * FROM `${cfg['db_table_prefix']}gpx_files` 
						WHERE `id` = '$id' ;";
			$result = db_query($query);
			if($DEBUG)	out($query, 'OUT_DEBUG');
			if(mysql_num_rows($result)) {
				while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
					$gpx = $row['name'];
				}
			}
		}
		
	    $query = "SELECT `gpx_id`, 
			MIN(`latitude`) AS 'minlat', MAX(`latitude`) AS 'maxlat', AVG(`latitude`) AS 'avglat', 
			MIN(`longitude`) AS 'minlon', MAX(`longitude`) AS 'maxlon', AVG(`longitude`) AS 'avglon'
			FROM `${cfg['db_table_prefix']}gpx_import` WHERE `gpx_id` = '$id' GROUP BY `gpx_id` ;";
	    $result = db_query($query);
		if($DEBUG)	out($query, 'OUT_DEBUG');
	    if(mysql_num_rows($result)) {
	    	while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
				#$f_lat = $row['avglat'] /1000000;
				#$f_lon = $row['avglon'] /1000000;
				$f_minlat = $row['minlat'] /1000000;
				$f_maxlat = $row['maxlat'] /1000000;
				$f_minlon = $row['minlon'] /1000000;
				$f_maxlon = $row['maxlon'] /1000000;
	    	}
		}
	}else {
		$f_lat = $cfg['home_latitude'];
		$f_lon = $cfg['home_longitude'];
		$zoom = $cfg['home_zoom'];
	}
}
?>

<!-- bring in the OpenLayers javascript library
	 (here we bring it from the remote site, but you could
	 easily serve up this javascript yourself)
	 URL: http://www.openlayers.org/api/OpenLayers.js -->
<?php
if($cfg['use_local_libs'])
	echo '<script src="openlayers/OpenLayers.js"></script>';
else
	echo '<script src="http://www.openlayers.org/api/OpenLayers.js"></script>';
?>
<!-- bring in the OpenStreetMap OpenLayers layers.
	 Using this hosted file will make sure we are kept up
	 to date with any necessary changes
	 URL: http://www.openstreetmap.org/openlayers/OpenStreetMap.js -->
<?php
if($cfg['use_local_libs'])
	echo '<script src="openlayers/OpenStreetMap.js"></script>';
else
	echo '<script src="http://www.openstreetmap.org/openlayers/OpenStreetMap.js"></script>';
?>
<script src="openlayers/GPX.js"></script>

<script type="text/javascript">
	// Start position for the map (hardcoded here for simplicity,
	// but maybe you want to get from URL params)
<?php
if($f_lat && $f_lon) {
?>	
	var lat=<?= $f_lat ?>;
	var lon=<?= $f_lon ?>;
	var zoom=<?= $zoom ?>;
<?php
}
?>	

	var map; //complex object of type OpenLayers.Map
 
	//Initialise the 'map' object
	function initMap() {
		map = new OpenLayers.Map ("map", {
			controls:[
				new OpenLayers.Control.Navigation(),
				new OpenLayers.Control.PanZoomBar(),
				new OpenLayers.Control.LayerSwitcher(),
				new OpenLayers.Control.Attribution()],
			maxExtent: new OpenLayers.Bounds(-20037508.34,-20037508.34,20037508.34,20037508.34),
			maxResolution: 156543.0399,
			numZoomLevels: 19,
			units: 'm',
			projection: new OpenLayers.Projection("EPSG:900913"),
			displayProjection: new OpenLayers.Projection("EPSG:4326")
		} );
 
 
		// Define the map layer
		// Note that we use a predefined layer that will be
		// kept up to date with URL changes
		// Here we define just one layer, but providing a choice
		// of several layers is also quite simple
		// Other defined layers are OpenLayers.Layer.OSM.Mapnik, OpenLayers.Layer.OSM.Maplint and OpenLayers.Layer.OSM.CycleMap
		
		layerMapnik = new OpenLayers.Layer.OSM.Mapnik("Mapnik");
		map.addLayer(layerMapnik);
		
		layerTilesAtHome = new OpenLayers.Layer.OSM.Osmarender("Osmarender");
		map.addLayer(layerTilesAtHome);
		
		layerCycleMap = new OpenLayers.Layer.OSM.CycleMap("CycleMap");
		map.addLayer(layerCycleMap);
		
<?php
if($marker && $f_lat && $f_lon) {
?>	
		layerMarkers = new OpenLayers.Layer.Markers("Markers");
		map.addLayer(layerMarkers);
		
<?php
}
if($gpx) {
?>
		// Add the Layer with GPX Track
		var lgpx = new OpenLayers.Layer.GPX("GPX-Track", "./files/<?= $gpx ?>", "#9900ff");
		map.addLayer(lgpx);
		
<?php
}
if($f_lat && $f_lon) {
?>	
		var lonLat = new OpenLayers.LonLat(lon, lat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject());
		map.setCenter (lonLat, zoom);
		
<?php
}else {
		echo "var minlon=$f_minlon;";
		echo "var maxlon=$f_maxlon;";
		echo "var minlat=$f_minlat;";
		echo "var maxlat=$f_maxlat;";
?>
		bounds = new OpenLayers.Bounds();
		bounds.extend(new OpenLayers.LonLat(minlon, minlat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()));
		bounds.extend(new OpenLayers.LonLat(maxlon, maxlat).transform(new OpenLayers.Projection("EPSG:4326"), map.getProjectionObject()));
		map.zoomToExtent(bounds);
		
<?php
}
if($marker && $f_lat && $f_lon) {
?>	
		var size = new OpenLayers.Size(21,25);
		var offset = new OpenLayers.Pixel(-(size.w/2), -size.h);
		var icon = new OpenLayers.Icon('http://www.openstreetmap.org/openlayers/img/marker.png',size,offset);
		layerMarkers.addMarker(new OpenLayers.Marker(lonLat,icon));
		
<?php
}
?>		
		// register event that records new lon/lat coordinates in form fields after panning
		map.events.register("moveend", map, function() {
			var pos = this.getCenter().clone();
			var lonlat = pos.transform(this.getProjectionObject(), new OpenLayers.Projection("EPSG:4326"));			
			var edit_bounds = map.getExtent();
			edit_bounds.transform(this.getProjectionObject(), new OpenLayers.Projection("EPSG:4326"));
			
			var bookmarklink = document.getElementById('bookmarklink');
			var searchlink = document.getElementById('searchlink');
			var josmlink = document.getElementById('josmlink');
			var osblink = document.getElementById('osblink');
			var keeprightlink = document.getElementById('keeprightlink');
			
			bookmarklink.value = "map.php?lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&zoom=" + this.getZoom();
			searchlink.href = "traces.php?task=view&option=search&lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&lat_range=" + edit_bounds.getHeight() + "&lon_range=" + edit_bounds.getWidth();
			josmlink.href = "http://localhost:8111/load_and_zoom?left=" + edit_bounds.left + "&right=" + edit_bounds.right + "&bottom=" + edit_bounds.bottom + "&top=" + edit_bounds.top;
			osblink.href = "http://openstreetbugs.org/?lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&z=" + this.getZoom();
			keeprightlink.href = "http://keepright.ipax.at/report_map.php?lat=" + lonlat.lat + "&lon=" + lonlat.lon + "&zoom=" + this.getZoom();
		});
	
	// call event handler as if one had moved the map
	map.events.triggerEvent("moveend");

	}
</script>

<script type="text/javascript">
	function addBookmark() {
		bookmarkName = prompt("<?= _MAP_JS_BOOKM_NAME ?>", "");
		if(bookmarkName) {
			var bookmarkScript = "bookmark.php?task=add&name=" + 
				encodeURIComponent(bookmarkName) + "&url=";
			var bookmarkLink = String(document.getElementById('bookmarklink').value);
			document.location.href = bookmarkScript + encodeURIComponent(bookmarkLink);
		}
	}
</script>

<!-- define a DIV into which the map will appear. Make it take up the whole window -->
<div style="width:99%; height:66%;" id="map"></div>

<img src="images/b_bookmark.png" />
<input type="hidden" name="url" id="bookmarklink" />
<a href="JavaScript:addBookmark();"><?= _MAP_ADD_BOOKM ?></a><br />
<img src="images/b_select.png" />
<a href="" id="searchlink"><?= _MAP_AREA_TRKPT ?></a><br />
<img src="images/icon_josm.png" />
<a target="josm" href="" id="josmlink"><?= _MAP_JOSM_EDIT ?></a><br />
<img src="images/icon_osb.png" />
<a target="osb" href="" id="osblink">OpenStreetBugs</a><br />
<img src="images/icon_keepright.png" />
<a target="keepright" href="" id="keeprightlink">keep right!</a><br />

<?php
if($cfg['show_exec_time']) {
    $endTime = microtime_float();
    $exectime = round($endTime - $startTime, 4);
}
include("./foot.html.php");
?>
